@@ -2,9 +2,10 @@ import os
 import subprocess
 from time import sleep
 
-from aws_cdk import App, RemovalPolicy, Stack
+from aws_cdk import App, Environment, RemovalPolicy, Stack
 from aws_cdk import aws_ec2 as ec2
 from aws_cdk import aws_efs as efs
+from aws_cdk import aws_elasticloadbalancingv2 as elb
 from aws_cdk import aws_iam as iam
 import requests
 
@@ -14,6 +15,8 @@ class AWSStack():
 		self.path = path
 		self.config = config
 		self.tool = tool
+		self.region = self.config['aws'].get('region', 'us-east-1')  # noqa: E501
+		self.use_https = self.config['aws'].get('https', False)
 
 		app = App()
 		_AWSStack(
@@ -21,7 +24,8 @@ class AWSStack():
 			f'substrate-stack-{self.tool.name}',
 			tool,
 			config,
-			self.tool.data_sources[1]
+			self.tool.data_sources[1],
+			env=Environment(region=self.region)
 		)
 		app.synth()
 
@@ -38,8 +42,9 @@ class AWSStack():
 			shell=True
 		)
 
+		# TODO: this needs to be different for HTTPS
 		location = subprocess.check_output(
-			f'aws ec2 describe-instances --filters Name=instance-state-name,Values=running Name=tag:Name,Values=substrate-stack-{self.tool.name}/substrate-leader --query Reservations[*].Instances[*].[PublicIpAddress] --output text',  # noqa: E501
+			f'aws ec2 describe-instances --region {self.region} --filters Name=instance-state-name,Values=running Name=tag:Name,Values=substrate-stack-{self.tool.name}/substrate-leader --query Reservations[*].Instances[*].[PublicIpAddress] --output text',  # noqa: E501
 			shell=True
 		).strip().decode('utf-8')
 
@@ -79,6 +84,8 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 		self.config = config
 		self.data_urls = data_urls
 		self.leader_name = ''
+		self.nodes = []
+		self.use_https = self.config['aws'].get('https', False)
 
 		self.tool.upload_to_s3()
 
@@ -97,7 +104,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 		ami_string = self.config['aws'].get('ami', None)
 		if ami_string:
 			self.ami = ec2.MachineImage.generic_linux({
-				self.config['aws'].get('region', 'us-east-1'): 'ami-048ff3da02834afdc'
+				self.region: 'ami-048ff3da02834afdc'
 			})
 		else:
 			self.ami = ec2.MachineImage.latest_amazon_linux(
@@ -112,6 +119,8 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 
 		self.file_system = self.provision_fs()
 		self.provision_ec2()
+		if self.use_https:
+			self.provision_elb()
 
 	def add_leader_commands(self, udata, *args):
 		for command in args:
@@ -124,7 +133,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 		udata = ec2.UserData.for_linux()
 		self.add_leader_commands(
 			udata,
-			f'export AWS_DEFAULT_REGION={self.config["aws"].get("region", "us-east-1")}',  # noqa: E501
+			f'export AWS_DEFAULT_REGION={self.region}',  # noqa: E501
 			f'export AWS_ACCESS_KEY_ID={os.environ.get("AWS_ACCESS_KEY_ID")}',
 			f'export AWS_SECRET_ACCESS_KEY={os.environ.get("AWS_SECRET_ACCESS_KEY")}',
 			f'export AWS_SESSION_TOKEN={os.environ.get("AWS_SESSION_TOKEN", "")}',
@@ -137,7 +146,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 			'sudo yum install -y nfs-utils',
 			'sudo yum install -y python3',
 			'sudo mkdir -p "/mnt/efs"',
-			f'test -f "/sbin/mount.efs" && echo "{self.file_system.file_system_id}:/ /mnt/efs efs defaults,_netdev" >> /etc/fstab || echo "{self.file_system.file_system_id}.efs.{self.config["aws"].get("region", "us-east-1")}.amazonaws.com:/ /mnt/efs nfs4 nfsvers=4.1,rsize=1048576,wsize=1048576,hard,timeo=600,retrans=2,noresvport,_netdev 0 0" >> /etc/fstab',  # noqa: E501
+			f'test -f "/sbin/mount.efs" && echo "{self.file_system.file_system_id}:/ /mnt/efs efs defaults,_netdev" >> /etc/fstab || echo "{self.file_system.file_system_id}.efs.{self.region}.amazonaws.com:/ /mnt/efs nfs4 nfsvers=4.1,rsize=1048576,wsize=1048576,hard,timeo=600,retrans=2,noresvport,_netdev 0 0" >> /etc/fstab',  # noqa: E501
 			'mount -a -t efs,nfs4 defaults',
 			'until mountpoint -d /mnt/efs; do mount -a -t efs,nfs4 defaults; done'
 		)
@@ -179,7 +188,6 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 		managers = self.config['aws'].get('managers', {})
 		workers = self.config['aws'].get('workers', {})
 
-		nodes = []
 		for index, _type in enumerate(managers):
 			count = managers.get(_type, 1)
 			for index2 in range(count):
@@ -190,7 +198,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 					instance_name = f'substrate-manager-{_type}-{index}'
 					udata = self.get_udata('manager')
 
-				nodes.append(ec2.Instance(
+				self.nodes.append(ec2.Instance(
 					self,
 					instance_name,
 					instance_type=ec2.InstanceType(instance_type_identifier=_type),
@@ -206,7 +214,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 
 			count = workers.get(_type, 1)
 			for index in range(count):
-				nodes.append(ec2.Instance(
+				self.nodes.append(ec2.Instance(
 					self,
 					f'substrate-worker-{_type}-{index}',
 					instance_type=ec2.InstanceType(instance_type_identifier=_type),
@@ -217,7 +225,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 					vpc_subnets=ec2.SubnetSelection(subnet_type=ec2.SubnetType.PUBLIC)
 				))
 
-		for node in nodes:
+		for node in self.nodes:
 			node.node.add_dependency(self.file_system.mount_targets_available)
 
 			if self.role:
@@ -230,6 +238,15 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 				'General Purpose'
 			)
 
+	def provision_elb(self):
+		load_balancer = elb.ApplicationLoadBalancer(
+			self,
+			'substrate-elb',
+			vpc=self.vpc
+		)
+		listener = load_balancer.add_listener('substrate-elb-listener', port=443)
+		listener.add_targets('substrate-ec2-targets', targets=self.nodes)
+
 	def provision_fs(self):
 		efs_sg = ec2.SecurityGroup(self, 'substrate-efs-sg', vpc=self.vpc)
 		efs_sg.add_ingress_rule(
